{% extends "bee_django_coin/base.html" %}
{% load bee_django_message_filter %}
{% block styles %}
    <style>

    </style>
{% endblock %}
{% block content %}

    <div class="text-center"><h3>{{ user_name }}的金币记录</h3></div>
    <div class="row">
        <div class="col-sm-3">金币</div>
        <div class="col-sm-3">原因</div>
        <div class="col-sm-3">操作</div>
        <div class="col-xs-12 col-sm-3">时间</div>
    </div>
    <hr style="margin: 10px auto;">

    {% for record in record_list %}
        <div class="row">
            <div class="col-sm-3">{% if record.coin > 0 %}+{% endif %}{{ record.coin }}</div>
            <div class="col-sm-3">{{ record.reason|default:"" }}</div>
            <div class="col-sm-3">{{ record.get_created_by_user_name }}</div>
            <div class="col-xs-12 col-sm-3">{{ record.created_at|local_datetime|date:"Y-m-d H:i:s" }}</div>
        </div>

        <hr style="margin: 10px auto;">

    {% endfor %}
    {% include 'bee_django_coin/paginator.html' %}
{% endblock %}
{% block scripts %}
    <script>

    </script>
{% endblock %}